@@ -3,7 +3,7 @@
 /* ========================================================================== */
 
 /* -----------------------------------------------------------------------------
- * CHOLMOD/Cholesky Module.  Version 0.6.  Copyright (C) 2005, Timothy A. Davis
+ * CHOLMOD/Cholesky Module.  Copyright (C) 2005-2006, Timothy A. Davis
  * The CHOLMOD/Cholesky Module is licensed under Version 2.1 of the GNU
  * Lesser General Public License.  See lesser.txt for a text of the license.
  * CHOLMOD is also available under other licenses; contact authors for details.
@@ -50,8 +50,8 @@
 
 #ifndef NCHOLESKY
 
-#include "cholmod_cholesky.h"
 #include "cholmod_internal.h"
+#include "cholmod_cholesky.h"
 
 #ifndef NSUPERNODAL
 #include "cholmod_supernodal.h"
@@ -255,10 +255,11 @@ static void perm
 	    switch (B->xtype)
 	    {
 
+#if 0
 		case CHOLMOD_REAL:
 		    /* this case is not used */
-		    ASSERT (0) ;
 		    break ;
+#endif
 
 		case CHOLMOD_COMPLEX:
 		    /* Y zomplex, B complex */
@@ -415,10 +416,11 @@ static void iperm
 	    switch (X->xtype)
 	    {
 
+#if 0
 		case CHOLMOD_REAL:
 		    /* this case is not used */
-		    ASSERT (0) ;
 		    break ;
+#endif
 
 		case CHOLMOD_COMPLEX:
 		    /* Y complex, X complex */
@@ -458,10 +460,11 @@ static void iperm
 	    switch (X->xtype)
 	    {
 
+#if 0
 		case CHOLMOD_REAL:
 		    /* this case is not used */
-		    ASSERT (0) ;
 		    break ;
+#endif
 
 		case CHOLMOD_COMPLEX:
 		    /* Y zomplex, X complex */
@@ -845,10 +848,11 @@ static void iptrans
 	    switch (X->xtype)
 	    {
 
+#if 0
 		case CHOLMOD_REAL:
 		    /* this case is not used */
-		    ASSERT (0) ;
 		    break ;
+#endif
 
 		case CHOLMOD_COMPLEX:
 		    /* Y complex, X complex  */
@@ -888,10 +892,11 @@ static void iptrans
 	    switch (X->xtype)
 	    {
 
+#if 0
 		case CHOLMOD_REAL:
 		    /* this case is not used */
-		    ASSERT (0) ;
 		    break ;
+#endif
 
 		case CHOLMOD_COMPLEX:
 		    /* Y zomplex, X complex  */
@@ -953,7 +958,7 @@ cholmod_dense *CHOLMOD(solve)
 {
     cholmod_dense *Y = NULL, *X = NULL ;
     Int *Perm ;
-    Int n, nrhs, ncols, ctype, xtype, k1, nr, ok ;
+    Int n, nrhs, ncols, ctype, xtype, k1, nr, ytype ;
 
     /* ---------------------------------------------------------------------- */
     /* check inputs */
@@ -1057,10 +1062,10 @@ cholmod_dense *CHOLMOD(solve)
 	/* ------------------------------------------------------------------ */
 
 #ifndef NSUPERNODAL
-
 	/* allocate workspace */
 	cholmod_dense *E ;
 	Int dual ;
+        Common->blas_ok = TRUE ;
 	dual = (L->xtype == CHOLMOD_REAL && B->xtype != CHOLMOD_REAL) ? 2 : 1 ;
 	Y = CHOLMOD(allocate_dense) (n, dual*nrhs, n, L->xtype, Common) ;
 	E = CHOLMOD(allocate_dense) (dual*nrhs, L->maxesize, dual*nrhs,
@@ -1079,24 +1084,30 @@ cholmod_dense *CHOLMOD(solve)
 
 	if (sys == CHOLMOD_A || sys == CHOLMOD_LDLt)
 	{
-	    ok = CHOLMOD(super_lsolve) (L, Y, E, Common) ;	   /* Y = L\Y */
-	    ok = ok && CHOLMOD(super_ltsolve) (L, Y, E, Common) ;  /* Y = L'\Y*/
+	    CHOLMOD(super_lsolve) (L, Y, E, Common) ;	    /* Y = L\Y */
+            CHOLMOD(super_ltsolve) (L, Y, E, Common) ;	    /* Y = L'\Y*/
 	}
 	else if (sys == CHOLMOD_L || sys == CHOLMOD_LD)
 	{
-	    ok = CHOLMOD(super_lsolve) (L, Y, E, Common) ;	   /* Y = L\Y */
+	    CHOLMOD(super_lsolve) (L, Y, E, Common) ;	    /* Y = L\Y */
 	}
 	else if (sys == CHOLMOD_Lt || sys == CHOLMOD_DLt)
 	{
-	    ok = CHOLMOD(super_ltsolve) (L, Y, E, Common) ;	   /* Y = L'\Y */
+	    CHOLMOD(super_ltsolve) (L, Y, E, Common) ;      /* Y = L'\Y*/
 	}
 	CHOLMOD(free_dense) (&E, Common) ;
 
 	iperm (Y, Perm, 0, nrhs, X) ;			    /* X = P'*Y */
 
-	if (CHECK_BLAS_INT && !ok)
+	if (CHECK_BLAS_INT && !Common->blas_ok)
 	{
-	    /* integer overflow in the BLAS */
+	    /* Integer overflow in the BLAS.  This is probably impossible,
+	     * since the BLAS were used to create the supernodal factorization.
+	     * It might be possible for the calls to the BLAS to differ between
+	     * factorization and forward/backsolves, however.  This statement
+	     * is untested; it does not appear in the compiled code if
+	     * CHECK_BLAS_INT is true (when the same integer is used in CHOLMOD
+	     * and the BLAS. */
 	    CHOLMOD(free_dense) (&X, Common) ;
 	}
 
@@ -1113,31 +1124,32 @@ cholmod_dense *CHOLMOD(solve)
 	/* solve using a simplicial LL' or LDL' factorization */
 	/* ------------------------------------------------------------------ */
 
-	if (L->xtype == CHOLMOD_REAL)
+	if (L->xtype == CHOLMOD_REAL && B->xtype == CHOLMOD_REAL)
 	{
-	    /* L is real, B is real/complex/zomplex, Y is real */
-	    if (B->xtype == CHOLMOD_REAL)
-	    {
-		/* solve with up to 4 columns of B at a time */
-		ncols = 4 ;
-		nr = MAX (4, nrhs) ;
-		Y = CHOLMOD(allocate_dense) (nr, n, nr, CHOLMOD_REAL, Common) ;
-	    }
-	    else
-	    {
-		/* solve with one column of B (real/imag), at a time */
-		ncols = 1 ;
-		Y = CHOLMOD(allocate_dense) (2, n, 2, CHOLMOD_REAL, Common) ;
-	    }
+	    /* L, B, and Y are all real */
+	    /* solve with up to 4 columns of B at a time */
+	    ncols = 4 ;
+	    nr = MAX (4, nrhs) ;
+	    ytype = CHOLMOD_REAL ;
+	}
+	else if (L->xtype == CHOLMOD_REAL)
+	{
+	    /* solve with one column of B (real/imag), at a time */
+	    ncols = 1 ;
+	    nr = 2 ;
+	    ytype = CHOLMOD_REAL ;
 	}
 	else
 	{
 	    /* L is complex or zomplex, B is real/complex/zomplex, Y has the
 	     * same complexity as L.  Solve with one column of B at a time. */
 	    ncols = 1 ;
-	    Y = CHOLMOD(allocate_dense) (1, n, 1, L->xtype, Common) ;
+	    nr = 1 ;
+	    ytype = L->xtype ;
 	}
 
+	Y = CHOLMOD(allocate_dense) (nr, n, nr, ytype, Common) ;
+
 	if (Common->status < CHOLMOD_OK)
 	{
 	    /* out of memory */
