@@ -301,6 +301,22 @@ R_init_Matrix(DllInfo *dll)
     Matrix_permSym = install("perm");
     Matrix_uploSym = install("uplo");
     Matrix_xSym = install("x");
+
+    Matrix_NS = R_FindNamespace(mkString("Matrix"));
+    if(Matrix_NS == R_UnboundValue)
+	error(_("missing 'Matrix' namespace: should never happen"));
+
+#ifdef DEBUG_Matrix
+    if(isEnvironment(Matrix_NS))
+	Rprintf("Matrix_NS: %s\n",
+		CHAR(asChar(eval(lang2(install("format"),Matrix_NS),
+				 R_GlobalEnv))));
+    else
+#else
+    if(!isEnvironment(Matrix_NS))
+#endif
+	error(_("Matrix namespace not determined correctly"));
+
 }
 
 void R_unload_Matrix(DllInfo *dll)
